#
# spec file for package metamail
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           metamail
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bdftopcf
BuildRequires:  libpipeline-devel
BuildRequires:  mkfontdir
BuildRequires:  ncurses-devel
Requires:       sharutils
Version:        2.7.19
Release:        bp156.5.6
Summary:        MIME Mail Handler
License:        GPL-2.0-only AND MIT
Group:          Productivity/Networking/Email/Utilities
Source:         metamail-2.7-19.tar.gz
Source1:        mimecheck
Source2:        mimecheck.1
Source3:        mimegrep-0.2.tar.xz
Source4:        mimelang-0.3.tar.gz
Patch0:         metamail-2.7-19-security.dif
Patch1:         metamail-2.7-19.dif
Patch2:         metamail-2.7-19-getline.dif
Patch3:         metamail-2.7-19-binderman.dif
Patch4:         metamail-2.7-19-fix-bashisms.patch
Patch5:         metamail-2.7-19-provide-filenames-for-attachments.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%bcond_with     font

%description
Metamail is required for reading multimedia mail messages (such as
those using the Andrew toolkit) with elm.

%prep
%setup -n metamail-2.7-19 -b 3 -b 4
%autopatch -p1

%build
    rm -f bin/mailserver
    rm -f bin/sun-message.csh
    make
    make -C fonts
    pushd ../mimegrep-0.2
	./autogen.sh
	%configure
	make %{?_smp_mflags}
    popd
    pushd ../mimelang-0.3
	make %{?_smp_mflags}
    popd

%install
    mkdir -p %{buildroot}%{_bindir} %{buildroot}%_mandir/man{1,4}
    make INSTROOT=%{buildroot}/usr INSTALL=install install-all
%if %{with font}
    mkdir -p %{buildroot}%{_datadir}/fonts/misc
    install -m 0644 fonts/heb8x13B.pcf %{buildroot}%{_datadir}/fonts/misc/
    gzip -9f %{buildroot}%{_datadir}/fonts/misc/heb8x13B.pcf
%endif
    install -m 755 %{S:1} %{buildroot}%{_bindir}/
    install -m 644 %{S:2} %{buildroot}%{_mandir}/man1/
    ln -sf mimecheck %{buildroot}%{_bindir}/mimezip
    ln -sf mimecheck %{buildroot}%{_bindir}/mimebzip
    ln -sf mimecheck %{buildroot}%{_bindir}/mimegzip
    pushd ../mimegrep-0.2
	make install DESTDIR=%{buildroot}
    popd
    pushd ../mimelang-0.3
	make install DESTDIR=%{buildroot}
    popd

%files
%defattr(-,root,root)
%doc README mailers.txt
%{_bindir}/audiocompose
%{_bindir}/audiosend
%{_bindir}/extcompose
%{_bindir}/getfilename
%{_bindir}/mailto
%{_bindir}/mailto-hebrew
%{_bindir}/metamail
%{_bindir}/metasend
%{_bindir}/mimeit
%{_bindir}/mimencode
%{_bindir}/mimecheck
%{_bindir}/mimelang
%{_bindir}/mimezip
%{_bindir}/mimebzip
%{_bindir}/mimegzip
%{_bindir}/mmencode
%{_bindir}/mgrep
%{_bindir}/patch-metamail
%{_bindir}/rcvAppleSingle
%{_bindir}/richtext
%{_bindir}/richtoatk
%{_bindir}/showaudio
%{_bindir}/showexternal
%{_bindir}/shownonascii
%{_bindir}/showpartial
%{_bindir}/showpicture
%{_bindir}/sndAppleSingle
%{_bindir}/splitmail
%{_bindir}/sun-audio-file
%{_bindir}/sun-message
%{_bindir}/sun-to-mime
%{_bindir}/sun2mime
%{_bindir}/uudepipe
%{_bindir}/uuenpipe
%doc %{_mandir}/man1/audiocompose.1.gz
%doc %{_mandir}/man1/audiosend.1.gz
%doc %{_mandir}/man1/extcompose.1.gz
%doc %{_mandir}/man1/getfilename.1.gz
%doc %{_mandir}/man1/mailto-hebrew.1.gz
%doc %{_mandir}/man1/mailto.1.gz
%doc %{_mandir}/man1/metamail.1.gz
%doc %{_mandir}/man1/metasend.1.gz
%doc %{_mandir}/man1/mgrep.1.gz
%doc %{_mandir}/man1/mime.1.gz
%doc %{_mandir}/man1/mimencode.1.gz
%doc %{_mandir}/man1/mimecheck.1.gz
%doc %{_mandir}/man1/mimelang.1.gz
%doc %{_mandir}/man1/mmencode.1.gz
%doc %{_mandir}/man1/patch-metamail.1.gz
%doc %{_mandir}/man1/richtext.1.gz
%doc %{_mandir}/man1/showaudio.1.gz
%doc %{_mandir}/man1/showexternal.1.gz
%doc %{_mandir}/man1/shownonascii.1.gz
%doc %{_mandir}/man1/showpartial.1.gz
%doc %{_mandir}/man1/showpicture.1.gz
%doc %{_mandir}/man1/splitmail.1.gz
%doc %{_mandir}/man4/mailcap.4.gz
%if %{with font}
%{_datadir}/fonts/misc/heb8x13B.pcf.gz
%endif

%changelog
* Wed Aug 17 2022 Dr. Werner Fink <werner@suse.de>
- Update ot mimelang-0.3
  * Avoid to run on NULL if no UTF-8 marker is found
* Thu Jul 29 2021 Dr. Werner Fink <werner@suse.de>
- Add simple mimelang tool to be able to check unicode block of
  UTF-8 MIME encoded e-mail subjects
* Wed Jul 10 2019 Dr. Werner Fink <werner@suse.de>
- Replace old mgrep script with new m(mime)grep written in hackweek
* Tue Jun 11 2019 olaf@aepfle.de
- Remove tcsh dependency by dropping bogus mailserver and
  sun-message.csh
- use autosetup, refresh all 5 patches
* Sat May 28 2016 mardnh@gmx.de
- add patches:
  * metamail-2.7-19-provide-filenames-for-attachments.patch
    rebased from Immanuel Halupczok original debian patch:
    https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=321968
* Sat Dec 27 2014 Led <ledest@gmail.com>
- rebase metamail-2.7-19-fix-bashisms.patch
* Thu Nov 27 2014 Led <ledest@gmail.com>
- fix bashisms in showaudio and mgrep scripts
- update patches:
  * metamail-2.7-19.dif
- add patches:
  * metamail-2.7-19-fix-bashisms.patch
* Tue Oct  7 2014 crrodriguez@opensuse.org
- xorg libraries are not needed for build, just bdftopcf and
  mkfontdir
* Tue Oct 20 2009 werner@suse.de
- Yet an other David Binderman fix (bnc#547909)
* Sun Aug 30 2009 coolo@novell.com
- provide Patch0
* Sun Jun  7 2009 ro@suse.de
- rename getline to my_getline to avoid conflict with function
  from glibc
* Mon Sep 15 2008 werner@suse.de
- Fix typo in mailto manual page (bnc#422090)
* Mon Sep 15 2008 werner@suse.de
- Avoid autobuild error
* Thu Jun 28 2007 werner@suse.de
- Add MIME check script usable e.g. in procmailrc filter rules
* Thu Mar 29 2007 rguenther@suse.de
- Add ncurses-devel BuildRequires
* Thu Feb 23 2006 werner@suse.de
- Fix for buffer overflow (bug #153145)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 schwab@suse.de
- Don't strip binaries.
* Fri Jul  1 2005 werner@suse.de
- Remove -fsigned-char (bug #93881)
* Fri Jun 10 2005 werner@suse.de
- Use declaration from stdio.h for gets(3)
* Thu May  6 2004 hmacht@suse.de
- added # norootforbuild in specfile
* Fri Mar 19 2004 werner@suse.de
- Fix date issue with locale: be always RFC 822 conform (#35828)
* Tue Mar  2 2004 werner@suse.de
- Fix security fix: sizeof(char*) is not equal to sizeof(char[250])
* Mon Feb  9 2004 werner@suse.de
- Security fix format-string bug and buffer overflow (bug #34369)
* Fri Jan 23 2004 werner@suse.de
- Fix declarations of the stuff to make gcc happy
* Fri Jun 13 2003 coolo@suse.de
- use BuildRoot
- really package mgrep (not just the man page :)
- use %%_mandir
* Tue Dec 17 2002 werner@suse.de
- New: mgrep which does similar to zgrep on mimencoded data
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Sat Jul 13 2002 schwab@suse.de
- mmencode: don't change mode of stdout.
* Mon Oct  1 2001 schwab@suse.de
- Fix quoting in shell scripts.
* Tue May 22 2001 werner@suse.de
- Remove space after ?= closing phrase
* Wed Mar  7 2001 uli@suse.de
- added xf86 to neededforbuild
* Wed Mar  7 2001 werner@suse.de
- Be sure that font directory exists
* Fri Dec 22 2000 werner@suse.de
- If terminal attributes will be restored then do this immediately
* Fri Dec 22 2000 werner@suse.de
- Declare standard functions
- Use putenv of glibc
- Print commando is lpr
- Use limits.h
- Use termios interface of glibc
* Mon Nov 27 2000 sndirsch@suse.de
- removed /usr/X11R6/lib/X11/fonts/misc/heb8x13B.pcf.gz
  from filelist (font already included in xf86 package)
* Fri Nov 17 2000 kukuk@suse.de
- fix Requires: sharutil -> sharutils
* Mon Nov 13 2000 ro@suse.de
- don't redeclare killpg
* Wed Oct 11 2000 werner@suse.de
- Fix bug within metasend (bug# 4099)
* Wed Jun  7 2000 ro@suse.de
- doc relocation
* Thu Mar  2 2000 werner@suse.de
- /usr/man -> /usr/share/man
* Tue Oct 19 1999 werner@suse.de
- If -o is used for mmencoding the file permissions should
  be the same as the input file
- Use Fopen within mmencode.c
- sendmail is stored in /usr/sbin/
- MAILCAPDIR is /etc
- showexternal: check for broken arguments
- mailto.c: don't be fooled by newlines
- Use RPM_OPT_FLAGS
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Aug 24 1999 uli@suse.de
- added -fsigned-char to CFLAGS (PPC)
* Fri Jul 17 1998 werner@suse.de
- Add C source fixes of RedHat against temp exploits
- Make sh and shell scripts using mktemp for temp files
- Use PAGER if set
- Use -o of uudecode to avoid attacks over net
* Tue May 27 1997 florian@suse.de
- fix shell script "audiosend"
* Sat Apr 26 1997 florian@suse.de
- update to new version 2.7-19 from debian
* Thu Jan  2 1997 florian@suse.de
- Bisherige Anpassungen mit der neusten debian-Version vergleichen
  und zusammenbringen.
- Die extra Fonts sind momentan nicht mehr dabei,
  sollten aber auch nicht fehlen...
